@@ -18,15 +18,17 @@ see the associated documentation.
    blast6
    blast7
    clustal
+   embl
    fasta
    fastq
+   genbank
+   gff3
    lsmat
    newick
    ordination
    phylip
    qseq
    stockholm
-   genbank
 
 .. currentmodule:: skbio.io.registry
 
@@ -56,8 +58,11 @@ User exceptions and warnings
    FileFormatError
    BLAST7FormatError
    ClustalFormatError
+   EMBLFormatError
    FASTAFormatError
    FASTQFormatError
+   GenBankFormatError
+   GFF3FormatError
    LSMatFormatError
    NewickFormatError
    OrdinationFormatError
@@ -66,6 +71,7 @@ User exceptions and warnings
    QUALFormatError
    StockholmFormatError
 
+
 Subpackages
 -----------
 
@@ -203,7 +209,8 @@ from ._exception import (UnrecognizedFormatError, FileFormatError,
                          FASTQFormatError, LSMatFormatError, NewickFormatError,
                          OrdinationFormatError, PhylipFormatError,
                          QSeqFormatError, QUALFormatError,
-                         StockholmFormatError)
+                         StockholmFormatError, GFF3FormatError,
+                         EMBLFormatError)
 from .registry import write, read, sniff, create_format, io_registry
 from .util import open
 
@@ -215,9 +222,11 @@ __all__ = ['write', 'read', 'sniff', 'open', 'io_registry', 'create_format',
            'FileFormatError',
            'BLAST7FormatError',
            'ClustalFormatError',
+           'EMBLFormatError',
            'FASTAFormatError',
            'FASTQFormatError',
            'GenBankFormatError',
+           'GFF3FormatError',
            'LSMatFormatError',
            'NewickFormatError',
            'OrdinationFormatError',
@@ -233,6 +242,7 @@ __all__ = ['write', 'read', 'sniff', 'open', 'io_registry', 'create_format',
 import_module('skbio.io.format.blast6')
 import_module('skbio.io.format.blast7')
 import_module('skbio.io.format.clustal')
+import_module('skbio.io.format.embl')
 import_module('skbio.io.format.fasta')
 import_module('skbio.io.format.fastq')
 import_module('skbio.io.format.lsmat')
@@ -241,6 +251,7 @@ import_module('skbio.io.format.ordination')
 import_module('skbio.io.format.phylip')
 import_module('skbio.io.format.qseq')
 import_module('skbio.io.format.genbank')
+import_module('skbio.io.format.gff3')
 import_module('skbio.io.format.stockholm')
 
 # This is meant to be a handy indicator to the user that they have done
