@@ -354,7 +354,7 @@ class TestIntervalUtil(unittest.TestCase):
         for fuzzy in fuzzy:
             try:
                 _assert_valid_fuzzy(fuzzy)
-            except:
+            except Exception:
                 self.assertTrue(False)
 
     def test_assert_valid_fuzzy_wrong_value(self):
@@ -446,6 +446,57 @@ class TestIntervalMetadata(unittest.TestCase, ReallyEqualMixin):
         with self.assertRaises(ValueError):
             IntervalMetadata(-1)
 
+    def test_upper_bound_is_none(self):
+        im = IntervalMetadata(None)
+        # should not raise error
+        im.add([(0, 1000000000)])
+        self.assertIsNone(im.upper_bound)
+        with self.assertRaisesRegex(
+                TypeError, 'upper bound is `None`'):
+            im._reverse()
+        with self.assertRaisesRegex(
+                TypeError, 'upper bound is `None`'):
+            IntervalMetadata.concat([self.im_1, im])
+
+    def test_init_copy_from(self):
+        for i in [None, 99, 999]:
+            obs = IntervalMetadata(i, self.im_1)
+            exp = IntervalMetadata(i)
+            exp.add(bounds=[(1, 2), (4, self.upper_bound)],
+                    metadata={'gene': 'sagA',  'bound': 0})
+            self.assertEqual(obs, exp)
+
+    def test_init_copy_from_empty(self):
+        for i in [None, 0, 9, 99, 999]:
+            obs = IntervalMetadata(i, self.im_empty)
+            exp = IntervalMetadata(i)
+            self.assertEqual(obs, exp)
+            # test it is shallow copy
+            self.assertIsNot(obs._intervals, self.im_empty._intervals)
+            self.assertIsNot(obs._interval_tree, self.im_empty._interval_tree)
+
+    def test_init_copy_from_shallow_copy(self):
+        obs = IntervalMetadata(self.upper_bound, self.im_2)
+        self.assertEqual(self.im_2, obs)
+        # test it is shallow copy
+        self.assertIsNot(obs._intervals, self.im_2._intervals)
+        self.assertIsNot(obs._interval_tree, self.im_2._interval_tree)
+        for i in range(self.im_2.num_interval_features):
+            i1, i2 = obs._intervals[i], self.im_2._intervals[i]
+            self.assertIsNot(i1, i2)
+            self.assertIsNot(i1.bounds, i2.bounds)
+            self.assertIsNot(i1.fuzzy, i2.fuzzy)
+            self.assertIsNot(i1._interval_metadata, i2._interval_metadata)
+            self.assertIsNot(i1.metadata, i2.metadata)
+            for k in i1.metadata:
+                self.assertIs(i1.metadata[k], i2.metadata[k])
+
+    def test_init_copy_from_error(self):
+        i = self.upper_bound - 1
+        with self.assertRaisesRegex(
+                ValueError, r'larger than upper bound \(%r\)' % i):
+            IntervalMetadata(i, self.im_2)
+
     def test_num_interval_features(self):
         self.assertEqual(self.im_empty.num_interval_features, 0)
         self.assertEqual(self.im_1.num_interval_features, 1)
@@ -516,6 +567,24 @@ class TestIntervalMetadata(unittest.TestCase, ReallyEqualMixin):
                     r'not equal \(%d != %d\)' % (self.upper_bound, n)):
                 im.merge(im1)
 
+    def test_merge_to_unbounded(self):
+        for im in [self.im_empty, self.im_1, IntervalMetadata(None)]:
+            obs = IntervalMetadata(None)
+            obs.merge(im)
+            self.assertIsNone(obs.upper_bound)
+            self.assertEqual(obs._intervals, im._intervals)
+
+    def test_merge_unbounded_to_bounded(self):
+        im = IntervalMetadata(None)
+        with self.assertRaisesRegex(
+                ValueError,
+                'Cannot merge an unbound IntervalMetadata object '
+                'to a bounded one'):
+            self.im_1.merge(im)
+        # original im is not changed
+        self.assertIsNone(im.upper_bound)
+        self.assertEqual(im._intervals, [])
+
     def test_sort(self):
         interval = Interval(
             self.im_2,
@@ -639,6 +708,14 @@ class TestIntervalMetadata(unittest.TestCase, ReallyEqualMixin):
         self.im_2.drop(self.im_2._intervals)
         self.assertEqual(self.im_2, self.im_empty)
 
+    def test_drop_negate(self):
+        intvl = self.im_2._intervals[0]
+        self.im_2.drop([intvl], negate=True)
+        self.assertEqual(len(self.im_2._intervals), 1)
+        self.assertEqual(self.im_2._intervals[0], intvl)
+        # test the dropped intvl was set to dropped
+        self.assertTrue(self.im_2_2.dropped)
+
     def test_reverse(self):
         self.im_2._reverse()
         Interval(
