@@ -56,8 +56,8 @@ Functions
 
 References
 ----------
-.. [1] V. Pawlowsky-Glahn, "Lecture Notes on Compositional Data Analysis"
-   (2007)
+.. [1] V. Pawlowsky-Glahn, J. J. Egozcue, R. Tolosana-Delgado (2015),
+   Modeling and Analysis of Compositional Data, Wiley, Chichester, UK
 
 .. [2] J. J. Egozcue.,  "Isometric Logratio Transformations for
    Compositional Data Analysis" Mathematical Geology, 35.3 (2003)
@@ -218,7 +218,7 @@ def multiplicative_replacement(mat, delta=None):
 
     zcnts = 1 - tot * delta
     if np.any(zcnts) < 0:
-        raise ValueError('The multiplicative replacment created negative '
+        raise ValueError('The multiplicative replacement created negative '
                          'proportions. Consider using a smaller `delta`.')
     mat = np.where(z_mat, delta, zcnts * mat)
     return mat.squeeze()
